# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_list_searches_response import V1alphaListSearchesResponse

class TestV1alphaListSearchesResponse(unittest.TestCase):
    """V1alphaListSearchesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaListSearchesResponse:
        """Test V1alphaListSearchesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaListSearchesResponse`
        """
        model = V1alphaListSearchesResponse()
        if include_optional:
            return V1alphaListSearchesResponse(
                searches = [
                    seqq.models.v1alpha_search.v1alphaSearch(
                        name = '', 
                        query = '', 
                        code = 'CODE_UNSPECIFIED', 
                        prefix = '', 
                        query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        query_duration = '', 
                        hits = [
                            seqq.models.v1alpha_hit.v1alphaHit(
                                saccver = '', 
                                pident = 1.337, 
                                length = '', 
                                mismatch = '', 
                                gapopen = '', 
                                qstart = '', 
                                qend = '', 
                                sstart = '', 
                                send = '', 
                                evalue = 1.337, 
                                bitscore = 1.337, )
                            ], 
                        state = 'STATE_UNSPECIFIED', 
                        error = seqq.models.rpc_status.rpcStatus(
                            message = '', 
                            details = [
                                {
                                    'key' : None
                                    }
                                ], ), 
                        blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(), 
                        blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                        tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), )
                    ],
                next_page_token = ''
            )
        else:
            return V1alphaListSearchesResponse(
        )
        """

    def testV1alphaListSearchesResponse(self):
        """Test V1alphaListSearchesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchState(str, Enum):
    """
    The current state of the Search.   - STATE_UNSPECIFIED: STATE_UNSPECIFIED is the default value.  - RUNNING: RUNNING is the search is running.  - SUCCEEDED: SUCCEEDED is the search succeeded.  - FAILED: FAILED is the search failed.
    """

    """
    allowed enum values
    """
    STATE_UNSPECIFIED = 'STATE_UNSPECIFIED'
    RUNNING = 'RUNNING'
    SUCCEEDED = 'SUCCEEDED'
    FAILED = 'FAILED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchState from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_list_integrations_response import V1alphaListIntegrationsResponse

class TestV1alphaListIntegrationsResponse(unittest.TestCase):
    """V1alphaListIntegrationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaListIntegrationsResponse:
        """Test V1alphaListIntegrationsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaListIntegrationsResponse`
        """
        model = V1alphaListIntegrationsResponse()
        if include_optional:
            return V1alphaListIntegrationsResponse(
                integrations = [
                    seqq.models.v1alpha_integration.v1alphaIntegration(
                        collection = '', 
                        name = '', 
                        sequence_id_prefix = '', 
                        etag = '', 
                        ncbi = seqq.models.v1alpha_integration_ncbi.v1alphaIntegrationNCBI(
                            manifest = '', 
                            uploads = {
                                'key' : ''
                                }, ), 
                        google_drive = seqq.models.v1alpha_integration_google_drive.v1alphaIntegrationGoogleDrive(
                            service_account_credentials = 'YQ==', ), )
                    ],
                next_page_token = ''
            )
        else:
            return V1alphaListIntegrationsResponse(
        )
        """

    def testV1alphaListIntegrationsResponse(self):
        """Test V1alphaListIntegrationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_integration_google_drive import V1alphaIntegrationGoogleDrive

class TestV1alphaIntegrationGoogleDrive(unittest.TestCase):
    """V1alphaIntegrationGoogleDrive unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaIntegrationGoogleDrive:
        """Test V1alphaIntegrationGoogleDrive
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaIntegrationGoogleDrive`
        """
        model = V1alphaIntegrationGoogleDrive()
        if include_optional:
            return V1alphaIntegrationGoogleDrive(
                service_account_credentials = 'YQ=='
            )
        else:
            return V1alphaIntegrationGoogleDrive(
        )
        """

    def testV1alphaIntegrationGoogleDrive(self):
        """Test V1alphaIntegrationGoogleDrive"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.api.seqq_service_api import SeqqServiceApi


class TestSeqqServiceApi(unittest.TestCase):
    """SeqqServiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SeqqServiceApi()

    def tearDown(self) -> None:
        pass

    def test_batch_create_sequences(self) -> None:
        """Test case for batch_create_sequences

        Create a batch of Sequences in a Collection.
        """
        pass

    def test_create_collection(self) -> None:
        """Test case for create_collection

        Create a Collection.
        """
        pass

    def test_create_integration(self) -> None:
        """Test case for create_integration

        Create an Integration.
        """
        pass

    def test_create_sequence(self) -> None:
        """Test case for create_sequence

        Create a Sequence in a Collection.
        """
        pass

    def test_delete_collection(self) -> None:
        """Test case for delete_collection

        Delete a Collection by name.
        """
        pass

    def test_delete_integration(self) -> None:
        """Test case for delete_integration

        Delete an Integration by name.
        """
        pass

    def test_delete_search(self) -> None:
        """Test case for delete_search

        Delete a Search by name.
        """
        pass

    def test_delete_sequence(self) -> None:
        """Test case for delete_sequence

        Delete a Sequence by name.
        """
        pass

    def test_get_collection(self) -> None:
        """Test case for get_collection

        Get a Collection by its name.
        """
        pass

    def test_get_integration(self) -> None:
        """Test case for get_integration

        Get an Integration by name.
        """
        pass

    def test_get_search(self) -> None:
        """Test case for get_search

        Get a Search by name.
        """
        pass

    def test_get_sequence(self) -> None:
        """Test case for get_sequence

        Get a Sequence by name.
        """
        pass

    def test_list_collections(self) -> None:
        """Test case for list_collections

        List Collections.
        """
        pass

    def test_list_integrations(self) -> None:
        """Test case for list_integrations

        List Integrations in a Collection.
        """
        pass

    def test_list_searches(self) -> None:
        """Test case for list_searches

        List Searches in a Collection.
        """
        pass

    def test_list_sequences(self) -> None:
        """Test case for list_sequences

        List Sequences in a Collection.
        """
        pass

    def test_start_search(self) -> None:
        """Test case for start_search

        Start a Search asynchronously.
        """
        pass

    def test_update_integration(self) -> None:
        """Test case for update_integration

        Update an Integration.
        """
        pass


if __name__ == '__main__':
    unittest.main()
